@@ -12,21 +12,26 @@ Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
  the GNU General Public License for more details.
 """
 
-from qt import usingQt5, Qt, RealQVariant, variantValue, QSize, QRect, QEvent
+from qt import Qt, RealQVariant, variantValue, QSize, QRect, QEvent
 from qt import QStyledItemDelegate, QLabel, QTextDocument, QStyle, QPalette, \
     QStyleOptionViewItem, QApplication
 
 from guiutil import Painter
 
+
 class RichTextColumnDelegate(QStyledItemDelegate):
+
     """enables rich text in a view"""
-    label = QLabel()
-    label.setIndent(5)
-    label.setTextFormat(Qt.RichText)
-    document = QTextDocument()
+    label = None
+    document = None
 
     def __init__(self, parent=None):
         super(RichTextColumnDelegate, self).__init__(parent)
+        if self.label is None:
+            self.label = QLabel()
+            self.label.setIndent(5)
+            self.label.setTextFormat(Qt.RichText)
+            self.document = QTextDocument()
 
     def paint(self, painter, option, index):
         """paint richtext"""
@@ -49,11 +54,14 @@ class RichTextColumnDelegate(QStyledItemDelegate):
             text = variantValue(index.model().data(index))
         self.document.setDefaultFont(option.font)
         self.document.setHtml(text)
-        return QSize(self.document.idealWidth() + 5, option.fontMetrics.height())
+        return QSize(self.document.idealWidth() + 5,
+                     option.fontMetrics.height())
+
 
 class RightAlignedCheckboxDelegate(QStyledItemDelegate):
+
     """as the name says. From
-    http://qt-project.org/faq/answer/how_can_i_align_the_checkboxes_in_a_view"""
+http://qt-project.org/faq/answer/how_can_i_align_the_checkboxes_in_a_view"""
 
     def __init__(self, parent, cellFilter):
         super(RightAlignedCheckboxDelegate, self).__init__(parent)
@@ -62,17 +70,23 @@ class RightAlignedCheckboxDelegate(QStyledItemDelegate):
     @staticmethod
     def __textMargin():
         """text margin"""
-        return QApplication.style().pixelMetric(QStyle.PM_FocusFrameHMargin) + 1
+        return QApplication.style().pixelMetric(
+            QStyle.PM_FocusFrameHMargin) + 1
 
     def paint(self, painter, option, index):
         """paint right aligned checkbox"""
         viewItemOption = QStyleOptionViewItem(option)
         if self.cellFilter(index):
             textMargin = self.__textMargin()
-            newRect = QStyle.alignedRect(option.direction, Qt.AlignRight,
-                 QSize(option.decorationSize.width() + 5, option.decorationSize.height()),
-                 QRect(option.rect.x() + textMargin, option.rect.y(),
-                 option.rect.width() - (2 * textMargin), option.rect.height()))
+            newRect = QStyle.alignedRect(
+                option.direction, Qt.AlignRight,
+                QSize(
+                    option.decorationSize.width() + 5,
+                    option.decorationSize.height()),
+                QRect(
+                    option.rect.x() + textMargin, option.rect.y(),
+                    option.rect.width() - (2 * textMargin),
+                    option.rect.height()))
             viewItemOption.rect = newRect
         QStyledItemDelegate.paint(self, painter, viewItemOption, index)
 
@@ -84,14 +98,17 @@ class RightAlignedCheckboxDelegate(QStyledItemDelegate):
             return False
         # make sure that we have a check state
         value = index.data(Qt.CheckStateRole)
-        if not value.isValid():
+        if not isinstance(value, int) and not value.isValid():
+            # in Python3, we get the python3 data type int
             return False
         # make sure that we have the right event type
         if event.type() == QEvent.MouseButtonRelease:
             textMargin = self.__textMargin()
-            checkRect = QStyle.alignedRect(option.direction, Qt.AlignRight,
-                  option.decorationSize,
-                  QRect(option.rect.x() + (2 * textMargin), option.rect.y(),
+            checkRect = QStyle.alignedRect(
+                option.direction, Qt.AlignRight,
+                option.decorationSize,
+                QRect(
+                    option.rect.x() + (2 * textMargin), option.rect.y(),
                     option.rect.width() - (2 * textMargin),
                     option.rect.height()))
             if not checkRect.contains(event.pos()):
@@ -101,8 +118,7 @@ class RightAlignedCheckboxDelegate(QStyledItemDelegate):
                 return False
         else:
             return False
-        if not usingQt5:
-            value = value.toInt()[0]
+        value = variantValue(value)
         if value == Qt.Checked:
             state = Qt.Unchecked
         else:
